@@ -66,10 +66,10 @@ vlog = custom_logger('send_rate')
 @app.task(base=SQLALchemyLoggingTask, time_limit=288000, soft_time_limit=287400)
 def send_rate(send_rate_id):
     slog = SchLog('send_rate')
-    vlog.debug('Send rate log id={} sheduled.'.format(send_rate_id))
+    vlog.debug('Send rate log id={} scheduled.'.format(send_rate_id))
     sr = RateSendLog.get(send_rate_id)
     if not sr:
-        vlog.debug('Send rate log id={} sheduled. but not found'.format(send_rate_id))
+        vlog.debug('Send rate log id={} scheduled. but not found'.format(send_rate_id))
         return False
     # if sr.status != 'waiting':
     #     vlog.warning('Send rate log id={} sheduled but not waiting! skip.'.format(send_rate_id))
@@ -151,15 +151,15 @@ def send_rate(send_rate_id):
 
         sr.headers = ','.join(new_hdrs)
 
-        vlog.debug('Starting write to file')
+        vlog.debug('Starting write to file. send_rate_id={} rate_table_id={}'.format(send_rate_id, sr.rate_table_id))
 
         att = None
         if sr.format in ['csv', 'xls']:
             if not objects_list.first():
                 sr.status = 'sent failed'
-                sr.err = 'No rates for rate_table_id {}'.format(sr.rate_table_id)
+                sr.err = 'No rates for send_rate_id={} rate_table_id={}'.format(send_rate_id, sr.rate_table_id)
                 sr.save()
-                vlog.warning('Send rate log id={} rate_table_id={} empty '.format(send_rate_id, sr.rate_table_id))
+                vlog.warning('Send rate log send_rate_id={} rate_table_id={} empty '.format(send_rate_id, sr.rate_table_id))
                 return
             vlog.debug('Preparing Send rate log')
             csvfile = io.StringIO()
@@ -169,11 +169,16 @@ def send_rate(send_rate_id):
             i = 0
             window_size = 1000  # or whatever limit you like
             rate_list = objects_list.all()
-            vlog.debug("things len: {}".format(len(rate_list)))
+            vlog.debug("send_rate send_rate_id={} rate_table_id={}, things len: {}".format(send_rate_id, sr.rate_table_id, len(rate_list)))
             for start in range(0, len(rate_list), window_size):
                 stop = start + window_size
+                vlog.debug(
+                    "send_rate send_rate_id={} rate_table_id={}. start={} stop={} window_size={} total_len={}".format(
+                        send_rate_id, sr.rate_table_id, start, stop, window_size, len(rate_list)
+                    )
+                )
                 temp = rate_list[start:stop]
-                if temp is None:
+                if not temp:
                     break
                 added = set()
                 for rate in temp:
@@ -205,17 +210,17 @@ def send_rate(send_rate_id):
                     added.add(data['code'])
                     writer.writerow(data)
                     i += 1
-                vlog.debug('Send rate {} records done'.format(i))
-                vlog.debug("Temp: {}:{}".format(start, stop))
-                vlog.debug("Temp: {} (first 10)".format(temp[:10]))
+                vlog.debug('send_rate_id={} Send rate {} records done'.format(send_rate_id, i))
+                vlog.debug("send_rate_id={} Temp: {}:{}".format(send_rate_id, start, stop))
+                vlog.debug("send_rate_id={} Temp: {} (first 10)".format(send_rate_id, temp[:10]))
                 if len(temp) < window_size:
                     vlog.debug('len(things) < window_size')
                     break
             sr.total_records = i
-            vlog.debug('Send rate log total_records={}'.format(sr.total_records))
+            vlog.debug('Send rate send_rate_id={} rate_table_id={}. log total_records={}'.format(send_rate_id, sr.rate_table_id, sr.total_records))
             acsv = csvfile.getvalue()
             csvfile.seek(0)
-            vlog.debug('Send rate log csv file ready')
+            vlog.debug('Send rate log csv file ready. send_rate_id={} rate_table_id={}'.format(send_rate_id, sr.rate_table_id))
             sr.completed_records = sum(1 for line in csvfile) - 1
             att = [('{}_{}.csv'.format(rt.name, datetime.now().strftime("%d%Y%m%d%H%M%S")), acsv)]
             if sr.format == 'xls':
@@ -230,7 +235,7 @@ def send_rate(send_rate_id):
             with zipfile.ZipFile(out, mode="w") as f:
                 f.writestr(name, att[0][1], zipfile.ZIP_DEFLATED)
             att = [(name, out.getvalue())]
-            vlog.debug('Send rate log zip file ready')
+            vlog.debug('Send rate log zip file ready. send_rate_id={} rate_table_id={}'.format(send_rate_id, sr.rate_table_id))
         method = 'attachment'
         #if sr.download_method == 'link' or
         sr.file = att[0][0]
@@ -250,24 +255,36 @@ def send_rate(send_rate_id):
         f.close()
         sr.status = 'generated'
         sr.save()
-        vlog.debug("Finished writing to file")
+        vlog.debug("Finished writing to file. send_rate_id={} rate_table_id={}".format(send_rate_id, sr.rate_table_id))
         vlog.warning(
-            'Send rate log id={} rate_table_id={} attachment {} generated '.format(send_rate_id, sr.rate_table_id,
+            'Send rate log send_rate_id={} rate_table_id={} attachment {} generated '.format(send_rate_id, sr.rate_table_id,
                                                                                    sr.file))
         errors = 0
         err_list = []
 
+        vlog.debug("Send rate. send_rate_id={} rate_table_id={} . send_type: {}, trunks: {}".format(send_rate_id, sr.rate_table_id, sr.send_type, sr.trunks))
         if sr.send_type in (
                 'Send to carriers using this rate table', 'Send to specified trunks', 'Send to specified carriers'):
             if sr.send_type == 'Send to carriers using this rate table':
                 if not sr.trunks:
+                    vlog.debug('send_rate. resource_ids. 1 method.')
                     res_pref = aliased(ResourcePrefix)
-                    q = Resource.query().outerjoin(res_pref).filter(or_(Resource.rate_table_id == sr.rate_table_id,
-                                                                res_pref.rate_table_id == sr.rate_table_id)).group_by(
-                        Resource.resource_id).all()
-                    trunks = []
-                    for tr in q:
-                        trunks.append(tr.resource_id)
+                    active_resources = (
+                        Resource.query()
+                        .filter(Resource.active == True, Resource.ingress == True)
+                        .with_entities(Resource.resource_id)
+                        .subquery()
+                    )
+                    q = (
+                        res_pref.query()
+                        .filter(
+                            res_pref.rate_table_id == sr.rate_table_id,
+                            res_pref.resource_id.in_(active_resources)
+                        )
+                        .all()
+                    )
+                    trunks = [tr.resource_id for tr in q]
+                    vlog.debug("send_rate. send_rate_id={}. trunks: {}".format(send_rate_id, trunks))
                     sr.trunks = trunks
                 else:
                     sr.send_type = 'Send to specified trunks'
@@ -311,7 +328,7 @@ def send_rate(send_rate_id):
                             else:
                                 res = trunk.apply_mail('sendratedirect_' + str(sr.id), email, att=att)
                             is_sent = True
-                        vlog.debug('Send rate apply mail res {}'.format(res))
+                        vlog.debug('send_rate_id={}. Send rate apply mail(1) res {}'.format(send_rate_id, res))
                         if res:
                             mail_sender_last_error = res[1]
                             l.error = mail_sender_last_error
@@ -374,7 +391,7 @@ def send_rate(send_rate_id):
                         res = MailSender.apply_mail(trunk, 'sendrate_' + str(sr.email_template_id), email, att=att)
                     else:
                         res = MailSender.apply_mail(trunk, 'sendratedirect_' + str(sr.id), email, att=att)
-                    vlog.debug('Send rate apply mail res {}'.format(res))
+                    vlog.debug('send_rate_id={}. Send rate apply mail(2) res {}'.format(send_rate_id, res))
                     if res:
                         mail_sender_last_error = res[1]
                         l.error = mail_sender_last_error
@@ -392,18 +409,19 @@ def send_rate(send_rate_id):
                     l.error = str(e)[0:500]
                     l.status = 'failed'
                     l.save()
+        vlog.debug('Send rate send_rate_id={}. errors={}'.format(send_rate_id, errors))
         if not errors:
             sr.status = 'sent success'
             sr.error = None
             sr.save()
-            vlog.debug('Send rate finished with success')
+            vlog.debug('Send rate finished with success. send_rate_id={}'.format(send_rate_id))
         else:
             try:
                 err_list = set(err_list)
                 e = ','.join(err_list)
             except:
                 e = 'mail send error'
-            vlog.debug('Send rate finished with srrors'.format(e))
+            vlog.debug('Send rate finished with errors. send_rate_id={}, errors={}'.format(send_rate_id, e))
             sr.status = 'sent failed'
             sr.err = 'Send rate mail failed {} times'.format(e)
             sr.save()
@@ -413,9 +431,9 @@ def send_rate(send_rate_id):
         sr.err = 'Send rate id={} error={}'.format(send_rate_id, str(e))
         try:
             sr.save()
-            vlog.error('Send rate id={} error={}'.format(send_rate_id, str(e)))
+            vlog.error('Send rate send_rate_id={} error={}'.format(send_rate_id, str(e)))
         except Exception as e:
-            vlog.error('Send rate id={} fatal error={}'.format(send_rate_id, str(e)))
+            vlog.error('Send rate send_rate_id={} fatal error={}'.format(send_rate_id, str(e)))
             db.session.rollback()
         slog.close()
         return False
@@ -425,6 +443,7 @@ def send_rate(send_rate_id):
 
 @app.task(base=SqlAlchemyTask, time_limit=1800, soft_time_limit=1790)
 def send_rate_task(rate_table_id, clients):
+    log.debug('send_rate_task start')
     slog = SchLog('send_rate_task')
     sr = RateSendLog(rate_table_id=rate_table_id, status='waiting')
     try:
@@ -441,11 +460,13 @@ def send_rate_task(rate_table_id, clients):
             cl = Client.get(client_id)
             if cl.resources and len(cl.resources):
                 trunks.append(cl.resources[0].resource_id)
+        log.debug(f'send_rate_task rate_table_id: {rate_table_id}, trunks: {trunks}')
         sr.trunks = trunks
         sr.send_type == 'Send to specified trunks'
         sr.format = 'csv'
         rate_id = sr.save()
         slog.close()
+        log.debug('send_rate_task end success')
         return send_rate(rate_id)
     except Exception as e:
         sr.status = 'sent failed'
@@ -457,6 +478,7 @@ def send_rate_task(rate_table_id, clients):
             log.error('Send rate task fatal error={}'.format(str(e)))
             db.session.rollback()
         slog.close()
+        log.debug('send_rate_task end error')
         return False
 
 
