@@ -463,12 +463,18 @@ class CdrReportList(DnlList):
         else:
             return or_(*[cdr.c.origination_destination_number.like('%{}%'.format(number)) for number in v.split(',')])
 
-    def on_filter_anis_fuzzy(self, v, cdr):
+    def on_filter_orig_ani_fuzzy(self, v, cdr):
         if ',' not in v:
             return cdr.c.origination_source_number.like('%{}%'.format(v))
         else:
             return or_(*[cdr.c.origination_source_number.like('%{}%'.format(number)) for number in v.split(',')])
 
+    def on_filter_term_ani_fuzzy(self, v, cdr):
+        if ',' not in v:
+            return cdr.c.termination_source_number.like('%{}%'.format(v))
+        else:
+            return or_(*[cdr.c.termination_source_number.like('%{}%'.format(number)) for number in v.split(',')])
+
     def on_filter_ani_no_prefix(self, v, cdr):
         return self.compare_plus(cdr.c.translation_ani, v)
 
